# sqgtool

![GitHub RepoSize](https://img.shields.io/github/repo-size/marixko/SQGTool)
![PyPI version](https://img.shields.io/pypi/v/sqgtool)
![Python version](https://img.shields.io/pypi/pyversions/sqgtool)
![Last commit](https://img.shields.io/github/last-commit/marixko/SQGTool)

This project is aimed to classify all sources observed with S-PLUS into three different classes: STAR, QSO, or GALAXY. 

## Table of Contents
* [General info](#general-info)
* [Setup](#setup)
* [Examples of use](#examples-of-use)
* [License](#license)

## General info
This project uses a pre-trained Random Forest algorithm in order to classify any source from the S-PLUS survey. The process of training the classifier is fully described in the paper "On the discovery of stars, quasars and galaxies in the Southern Hemisphere with S-PLUS", submitted to the Monthly Notices of the Royal Astronomical Society (MNRAS) journal.

## Prerequisites
Before you begin, ensure you have met the following requirements:
* You have installed Python 3 or above


## Setup

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install sqgtool: 
```
pip install sqgtool

```

## Examples of use
To be done

## Contributions

To contribute to this project, follow these steps:

1. Fork this repository.
2. Create a branch: git checkout -b <branch_name>.
3. Make your changes and commit them: git commit -m '<commit_message>'
4. Push to the original branch: git push origin <project_name>/<location>
5. Create the pull request.

If you have any problems with the package, please open a new issue!

## License
This project uses the [MIT](https://choosealicense.com/licenses/mit/) license.